/**
 * @packageDocumentation
 * @module Boolean
 */
import { Observable, ObservableInput } from 'rxjs';
import { ArrayOrSet } from '../types/array-set';
/**
 * Returns an Observable that emits boolean values from passed source of values.
 *
 * @category Create
 *
 * @typeParam T Type of the value from the source Observable
 * @typeParam A Input types accepted to convert to boolean
 *
 * @param args Input values to create the Observable source from
 *
 * @example
 * Create an Observable that emits a single boolean value from a string, flip the value
 * ```ts
 * fromBoolean('Hello RxJS Ninja').pipe(flip()).subscribe();
 * ```
 * Output: `false`
 *
 * @example
 * Create an Observable that emits a single boolean from an array of values
 * ```ts
 * fromBoolean(['', 'Hello', 'RxJS', '']).subscribe();
 * ```
 * Output: `false, true, true, false`;
 *
 * @returns Observable that emits boolean values of the source value

 */
export declare function fromBoolean<T extends unknown, A extends ObservableInput<ArrayOrSet<T> | T> | PromiseLike<ArrayOrSet<T> | T> | ArrayOrSet<T> | T>(...args: A[]): Observable<boolean>;
